==> apache-marmotta-3.2.1-src.zip: apache-marmotta-3.2.1/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/webservices/config/DependenciesWebService.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.platform.core.webservices.config;

import org.apache.marmotta.platform.core.api.config.DependenciesService;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import java.util.List;
import java.util.Map;

/**
 * Exposes details about the current core dependencies
 * 
 * @author Sergio Fernández
 */
@ApplicationScoped
@Path("/dependencies")
public class DependenciesWebService {

    @Inject
    private DependenciesService dependenciesService;

    @GET
    @Path("/")
    @Produces("application/json")
    public List<Map<String, String>> getArtifacs() {
        return dependenciesService.getArtifacs();
    }

    @GET
    @Path("/{groupId: [a-z]+(\\.[a-z]+)*}")
    @Produces("application/json")
    public List<Map<String, String>> getArtifacs(@PathParam("groupId") String groupId) {
        return dependenciesService.getArtifacs(groupId);
    }

    @GET
    @Path("/{groupId: [a-z]+(\\.[a-z]+)*}/{artifactId: [a-z]+(\\.[a-z]+)*}")
    @Produces("application/json")
    public String getVersion(@PathParam("groupId") String groupId, @PathParam("artifactId") String artifactId) {
        return dependenciesService.getVersion(groupId, artifactId);
    }

}

==> apache-marmotta-3.3.0-src.zip: apache-marmotta-3.3.0/platform/marmotta-core/src/main/java/org/apache/marmotta/platform/core/webservices/config/DependenciesWebService.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.platform.core.webservices.config;

import org.apache.marmotta.platform.core.api.config.DependenciesService;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import java.util.List;
import java.util.Map;

/**
 * Exposes details about the current core dependencies
 * 
 * @author Sergio Fernández
 */
@ApplicationScoped
@Path("/dependencies")
public class DependenciesWebService {

    @Inject
    private DependenciesService dependenciesService;

    @GET
    @Path("/")
    @Produces("application/json")
    public List<Map<String, String>> getArtifacs() {
        return dependenciesService.getArtifacts();
    }

    @GET
    @Path("/{groupId: [a-z]+(\\.[a-z]+)*}")
    @Produces("application/json")
    public List<Map<String, String>> getArtifacs(@PathParam("groupId") String groupId) {
        return dependenciesService.getArtifacts(groupId);
    }

    @GET
    @Path("/{groupId: [a-z]+(\\.[a-z]+)*}/{artifactId: [a-z]+(\\.[a-z]+)*}")
    @Produces("application/json")
    public String getVersion(@PathParam("groupId") String groupId, @PathParam("artifactId") String artifactId) {
        return dependenciesService.getVersion(groupId, artifactId);
    }

}
